@@ -56,7 +56,7 @@
     of ConfigSection subclasses each defining parsed attributes. 
 
     The ini file may only contain entries defined in this template.
-    In case an unkown section is found, the main class is looked up
+    In case an unknown section is found, the main class is looked up
     for a ConfigSection subclass with name 'DefaultSection'. This
     section object is then taken as template for a new section
     of the given name.
@@ -72,6 +72,7 @@
         characters and spanning multiple lines)
 
     Copyright (c) 2000, Marc-Andre Lemburg; All Rights Reserved.
+    Copyright (c) 2000-2009, eGenix.com Software GmbH; All Rights Reserved.
     See the documentation for further information on copyrights,
     or contact the author. All Rights Reserved.
 
@@ -218,11 +219,21 @@ class Entry:
 
 ###
 
+def integer_value(value):
+
+    """ Convert value to an integer.
+
+        Takes base indicators into account, such as 0x for base-16,
+        0 for base-7.
+
+    """
+    return int(value, 0)
+
 class IntegerEntry(Entry):
 
     """ Converts the value to an integer.
     """
-    converters = (int,)
+    converters = (integer_value,)
         
 class FloatEntry(Entry):
 
@@ -234,7 +245,7 @@ class NumericEntry(Entry):
 
     """ Converts the value to a number (integer or float).
     """
-    converters = (int,float)
+    converters = (integer_value, float)
         
 class StringEntry(Entry):
 
@@ -638,7 +649,6 @@ class ConfigNamespace(Namespace.Namespace):
                              types.NoneType,
                              ),
                  del_types=(types.FunctionType,
-                            types.UnboundMethodType,
                             types.MethodType,
                             types.BuiltinFunctionType,
                             types.BuiltinMethodType,),
@@ -852,7 +862,7 @@ class ConfigFile:
                         setattr(data,sectionname,section)
                     else:
                         raise Error,(current_lineno,
-                                     'unkown section "%s"' % 
+                                     'unknown section "%s"' % 
                                      sectionname)
                 #print 'Switched to section:',sectionname
                 locals = section.__dict__
@@ -875,7 +885,14 @@ class ConfigFile:
                         setattr(section,name,entry)
                     else:
                         raise Error,(current_lineno,
-                                     'unkown attribute: "%s"' % attrname)
+                                     'unknown attribute: "%s"' % attrname)
+                if not isinstance(entry, Entry):
+                    # Since we replace the parsed entries with their parsed
+                    # value any occurance of non-Entry instances point
+                    # to a duplicate definition of an entry
+                    raise Error,(current_lineno,
+                                 'duplicate attribute definition for "%s"' %
+                                 attrname)
                 try:
                     entry.parse(value,locals,globals)
                 except:
